@@ -1,12 +1,20 @@
 /*
- * This file or a portion of this file is licensed under the
- * terms of the Globus Toolkit Public License, found at
- * http://www.globus.org/toolkit/download/license.html.
- * If you redistribute this file, with or without
- * modifications, you must include this notice in the file.
+ * Copyright 1999-2014 University of Chicago
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
-#include "globus_config.h"
-#ifdef TARGET_ARCH_WIN32
+
+#ifdef _WIN32
 #include "globus_i_xio_win32.h"
 
 /**
@@ -42,7 +50,7 @@
  *
  *
  * This implementation is based on #2
- * NOTE: cancelation of file i/o will not be supported at this time because
+ * NOTE: cancellation of file i/o will not be supported at this time because
  * CancelIo does not discriminate between read or write operations.
  *
  * Blocking io of overlapped handles is implemented by queuing asynchronous
