@@ -528,7 +528,6 @@ globus_l_xio_test_read_buffer(
 {
     globus_size_t                       offset=0;
     globus_size_t                       left = message_size;
-    globus_size_t                       to_read;
     globus_size_t                       nbytes;
     globus_result_t                     result = GLOBUS_SUCCESS;
     globus_byte_t *                     buffer;
@@ -548,8 +547,6 @@ globus_l_xio_test_read_buffer(
     while ((left > 0) || (result == GLOBUS_SUCCESS))
     {
         nbytes = 0;
-        to_read = (left > buffer_size) ? buffer_size : 
-                (left > 0 ? left : buffer_size);
         result = globus_xio_read(
                 handle,
                 buffer,
